@@ -4,17 +4,27 @@ use utf8;
 
 package Ukigumo::Client::Executor::Command;
 use Mouse;
+use Mouse::Util::TypeConstraints;
 use Ukigumo::Constants;
 
+subtype 'ArrayRefOfStrs', as 'ArrayRef[Str]';
+coerce 'ArrayRefOfStrs', from 'Str', via { [$_] };
+
 has command => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => 'ArrayRefOfStrs',
     required => 1,
+    coerce   => 1,
 );
 
 sub run {
     my ($self, $c) = @_;
-    return $c->tee($self->command)==0 ? STATUS_SUCCESS : STATUS_FAIL;
+
+    for my $command (@{ $self->command }) {
+        return STATUS_FAIL if $c->tee($command) != 0;
+    }
+
+    return STATUS_SUCCESS;
 }
 
 1;
@@ -27,4 +37,3 @@ Ukigumo::Client::Executor::Command - runs command
 =head1 DESCRIPTION
 
 This executor runs command.
-
